@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 import logging
 import re
 from inspect import ismethod
-from typing import Dict, Any, Optional, List, Union
+from typing import Dict, Any, Optional, List, Union, TYPE_CHECKING, Callable, cast
 
 from checkov.cloudformation.graph_builder.graph_components.block_types import BlockType
 from checkov.cloudformation.graph_builder.graph_components.blocks import CloudformationBlock
@@ -12,22 +14,29 @@ from checkov.cloudformation.parser.cfn_keywords import IntrinsicFunctions, Condi
 from checkov.common.parsers.node import DictNode
 from checkov.common.graph.graph_builder import Edge
 from checkov.common.graph.graph_builder.local_graph import LocalGraph
+from checkov.common.util.consts import START_LINE, END_LINE
 from checkov.common.util.data_structures_utils import search_deep_keys
 from checkov.cloudformation.graph_builder.graph_components.generic_resource_encryption import ENCRYPTION_BY_RESOURCE_TYPE
 
+if TYPE_CHECKING:
+    from checkov.common.graph.graph_builder.graph_components.blocks import Block
 
-class CloudformationLocalGraph(LocalGraph):
+TOKENIZED_FIELD_PATTERN = re.compile(r'\${([a-zA-Z0-9.]*)}')
+
+
+class CloudformationLocalGraph(LocalGraph[CloudformationBlock]):
     SUPPORTED_RESOURCE_ATTR_CONNECTION_KEYS = (ResourceAttributes.DEPENDS_ON, IntrinsicFunctions.CONDITION)
     SUPPORTED_FN_CONNECTION_KEYS = (IntrinsicFunctions.GET_ATT, ConditionFunctions.IF,
                                     IntrinsicFunctions.REF, IntrinsicFunctions.FIND_IN_MAP, IntrinsicFunctions.CONDITION)
 
-    def __init__(self, cfn_definitions: Dict[str, DictNode], source: str = "CloudFormation") -> None:
+    def __init__(self, cfn_definitions: dict[str, dict[str, Any]], source: str = "CloudFormation") -> None:
         super().__init__()
         self.definitions = cfn_definitions
         self.source = source
-        self._vertices_indexes = {}
-        self.transform_pre = {}
-        self._edges_set = set()
+        self.vertices: "list[CloudformationBlock]" = []
+        self._vertices_indexes: "dict[str, dict[str, int]]" = {}
+        self.transform_pre: "dict[str, Any]" = {}
+        self._edges_set: "set[Edge]" = set()
         self._connection_key_func = {
             IntrinsicFunctions.GET_ATT: self._fetch_getatt_target_id,
             ConditionFunctions.IF: self._fetch_if_target_id,
@@ -50,22 +59,14 @@ class CloudformationLocalGraph(LocalGraph):
         self.calculate_encryption_attribute(ENCRYPTION_BY_RESOURCE_TYPE)
 
     def _create_vertices(self) -> None:
-
-        def extract_resource_attributes(resource: DictNode) -> DictNode:
-            resource_type = resource.get("Type")
-            attributes = resource.get("Properties", {})
-            if not isinstance(attributes, dict):
-                attributes = DictNode({}, resource.start_mark, resource.end_mark)
-            attributes["resource_type"] = resource_type
-            attributes["__startline__"] = resource.get("__startline__")
-            attributes["__endline__"] = resource.get("__endline__")
-            attributes.start_mark = resource.start_mark
-            attributes.end_mark = attributes.end_mark
-            return attributes
-
         for file_path, file_conf in self.definitions.items():
-            self._create_section_vertices(file_path, file_conf, TemplateSections.RESOURCES,
-                                          BlockType.RESOURCE, extract_resource_attributes)
+            self._create_section_vertices(
+                file_path,
+                file_conf,
+                TemplateSections.RESOURCES,
+                BlockType.RESOURCE,
+                self.extract_resource_attributes,  # type:ignore[arg-type]
+            )
             self._create_section_vertices(file_path, file_conf, TemplateSections.OUTPUTS, BlockType.OUTPUTS)
             self._create_section_vertices(file_path, file_conf, TemplateSections.MAPPINGS, BlockType.MAPPINGS)
             self._create_section_vertices(file_path, file_conf, TemplateSections.CONDITIONS,
@@ -79,13 +80,31 @@ class CloudformationLocalGraph(LocalGraph):
             self.vertices_by_block_type[vertex.block_type].append(i)
             self.vertices_block_name_map[vertex.block_type][vertex.name].append(i)
 
-    def _create_section_vertices(self, file_path: str, file_conf: dict, section: TemplateSections,
-                                 block_type: str, attributes_operator: callable = lambda a: a) -> None:
+    def extract_resource_attributes(self, resource: DictNode) -> DictNode:
+        resource_type = resource.get("Type")
+        attributes: "DictNode" = resource.get("Properties", {})
+        if not isinstance(attributes, dict):
+            attributes = DictNode({}, resource.start_mark, resource.end_mark)
+        attributes["resource_type"] = resource_type
+        attributes[START_LINE] = resource.get(START_LINE)
+        attributes[END_LINE] = resource.get(END_LINE)
+        attributes.start_mark = resource.start_mark
+        attributes.end_mark = attributes.end_mark
+        return attributes
+
+    def _create_section_vertices(
+        self,
+        file_path: str,
+        file_conf: dict[str, Any],
+        section: TemplateSections,
+        block_type: str,
+        attributes_operator: Callable[[dict[str, Any]], dict[str, Any]] = lambda a: a,
+    ) -> None:
         for name, obj in get_only_dict_items(file_conf.get(section.value, {})).items():
             is_resources_section = section == TemplateSections.RESOURCES
             attributes = attributes_operator(obj)
             block_name = name if not is_resources_section else f"{obj.get('Type', 'UnTyped')}.{name}"
-            config = obj if not is_resources_section else obj.get("Properties")
+            config = obj if not is_resources_section else cast("dict[str, Any]", obj.get("Properties"))
             metadata = obj.get("Metadata")
             id = f"{block_type}.{block_name}" if not is_resources_section else block_name
             self.vertices.append(CloudformationBlock(
@@ -103,7 +122,7 @@ class CloudformationLocalGraph(LocalGraph):
                 self._vertices_indexes[file_path] = {}
             self._vertices_indexes[file_path][name] = len(self.vertices) - 1
 
-    def _add_sam_globals(self):
+    def _add_sam_globals(self) -> None:
         # behaviour regarding overrides
         # https://docs.aws.amazon.com/serverless-application-model/latest/developerguide/sam-specification-template-anatomy-globals.html#sam-specification-template-anatomy-globals-overrideable
         for index in self.vertices_by_block_type.get(BlockType.GLOBALS, []):
@@ -117,7 +136,7 @@ class CloudformationLocalGraph(LocalGraph):
             ]
 
             for property, value in globals_vertex.attributes.items():
-                if property.endswith(("__startline__", "__endline__")):
+                if property.endswith((START_LINE, END_LINE)):
                     continue
 
                 for vertex in related_vertices:
@@ -154,7 +173,7 @@ class CloudformationLocalGraph(LocalGraph):
                     hash_breadcrumbs.append(breadcrumb_data)
                 vertex.breadcrumbs[attribute_key] = hash_breadcrumbs
 
-    def _add_resource_attr_connections(self, attribute):
+    def _add_resource_attr_connections(self, attribute: str) -> None:
         if attribute not in self.SUPPORTED_RESOURCE_ATTR_CONNECTION_KEYS:
             return
         for origin_node_index, vertex in enumerate(self.vertices):
@@ -181,7 +200,7 @@ class CloudformationLocalGraph(LocalGraph):
                         f"and vertex_path {vertex_path} as target_ids is not a list"
                     )
 
-    def _extract_source_value_attrs(self, matching_path):
+    def _extract_source_value_attrs(self, matching_path: list[Any]) -> tuple[str, Any, list[Any]]:
         """ matching_path for Resource = [template_section, source_id, 'Properties', ... , key, value]
          matching_path otherwise = # matching_path for Resource = [template_section, source_id, ... , key, value]
          key = a member of SUPPORTED_FN_CONNECTION_KEYS """
@@ -192,7 +211,7 @@ class CloudformationLocalGraph(LocalGraph):
         attributes = matching_path[attrs_starting_index:-2]
         return source_id, value, attributes
 
-    def _add_fn_connections(self, key) -> None:
+    def _add_fn_connections(self, key: str) -> None:
         if key not in self.SUPPORTED_FN_CONNECTION_KEYS:
             return
         extract_target_id_func = self._connection_key_func.get(key, None)
@@ -210,29 +229,31 @@ class CloudformationLocalGraph(LocalGraph):
                     if origin_vertex_index is not None and dest_vertex_index is not None:
                         self._create_edge(origin_vertex_index, dest_vertex_index, label)
 
-    def search_deep_keys(self, searchText, cfndict, includeGlobals=True):
+    def search_deep_keys(self, searchText: str, cfndict: dict[str, Any], includeGlobals: bool = True) -> list[list[Any]]:
         """
             Search for a key in all parts of the template.
             :return if searchText is "Ref", an array like ['Resources', 'myInstance', 'Properties', 'ImageId', 'Ref', 'Ec2ImageId']
         """
-        logging.debug('Search for key %s as far down as the template goes', searchText)
-        results = []
+        logging.debug(f'Search for key {searchText} as far down as the template goes')
+
+        results: "list[list[int | str]]" = []
         results.extend(search_deep_keys(searchText, cfndict, []))
         # Globals are removed during a transform.  They need to be checked manually
         if includeGlobals:
-            pre_results = search_deep_keys(searchText, self.transform_pre.get('Globals'), [])
+            cfn_globals: "dict[str, Any] | None" = self.transform_pre.get('Globals')
+            pre_results = search_deep_keys(searchText, cfn_globals, [])
             for pre_result in pre_results:
-                results.append(['Globals'] + pre_result)
+                results.append(['Globals', *pre_result])
         return results
 
-    def _fetch_if_target_id(self, cfndict, value) -> Optional[int]:
+    def _fetch_if_target_id(self, cfndict: dict[str, Any], value: Any) -> Optional[int]:
         target_id = None
         # value = [condition_name, value_if_true, value_if_false]
         if isinstance(value, list) and len(value) == 3 and (self._is_of_type(cfndict, value[0], TemplateSections.CONDITIONS)):
             target_id = value[0]
         return target_id
 
-    def _fetch_getatt_target_id(self, cfndict, value) -> Optional[int]:
+    def _fetch_getatt_target_id(self, cfndict: dict[str, Any], value: Any) -> Optional[int]:
         """ might be one of the 2 following notations:
          1st: { "Fn::GetAtt" : [ "logicalNameOfResource", "attributeName" ] }
          2nd: { "!GetAtt" : "logicalNameOfResource.attributeName" } """
@@ -250,7 +271,7 @@ class CloudformationLocalGraph(LocalGraph):
 
         return target_id
 
-    def _fetch_ref_target_id(self, cfndict, value) -> Optional[int]:
+    def _fetch_ref_target_id(self, cfndict: dict[str, Any], value: Any) -> int | str | None:
         target_id = None
         # value might be a string or a list of strings
         if isinstance(value, (str, int)) \
@@ -258,7 +279,7 @@ class CloudformationLocalGraph(LocalGraph):
             target_id = value
         return target_id
 
-    def _fetch_connection_target_id(self, cfndict, value) -> Optional[int]:
+    def _fetch_connection_target_id(self, cfndict: dict[str, Any], value: Any) -> int | str | None:
         target_id = None
         # value might be a string or a list of strings
         if isinstance(value, (str, int)) \
@@ -266,14 +287,14 @@ class CloudformationLocalGraph(LocalGraph):
             target_id = value
         return target_id
 
-    def _fetch_findinmap_target_id(self, cfndict, value) -> Optional[int]:
+    def _fetch_findinmap_target_id(self, cfndict: dict[str, Any], value: Any) -> Optional[int]:
         target_id = None
         # value = [ MapName, TopLevelKey, SecondLevelKey ]
         if isinstance(value, list) and len(value) == 3 and (self._is_of_type(cfndict, value[0], TemplateSections.MAPPINGS)):
             target_id = value[0]
         return target_id
 
-    def _add_fn_sub_connections(self):
+    def _add_fn_sub_connections(self) -> None:
         for file_path, cfndict in self.definitions.items():
             # add edges for "Fn::Sub" tags. E.g. { "Fn::Sub": "arn:aws:ec2:${AWS::Region}:${AWS::AccountId}:vpc/${vpc}" }
             sub_objs = self.search_deep_keys(IntrinsicFunctions.SUB, cfndict)
@@ -300,17 +321,19 @@ class CloudformationLocalGraph(LocalGraph):
                         if origin_vertex_index is not None and dest_vertex_index is not None:
                             self._create_edge(origin_vertex_index, dest_vertex_index, label)
 
-    def _extract_origin_dest_label(self, file_path, source_id, target_id, attributes):
+    def _extract_origin_dest_label(
+        self, file_path: str, source_id: str, target_id: str, attributes: list[Any]
+    ) -> tuple[int | None, int | None, str]:
         origin_vertex_index = self._vertices_indexes.get(file_path, {}).get(source_id, None)
         dest_vertex_index = self._vertices_indexes.get(file_path, {}).get(target_id, None)
         attributes_joined = '.'.join(map(str, attributes))  # mapping all attributes to str because one of the attrs might be an int
         return origin_vertex_index, dest_vertex_index, attributes_joined
 
     @staticmethod
-    def _find_fn_sub_parameter(string):
+    def _find_fn_sub_parameter(string: str) -> list[str]:
         """Search string for tokenized fields"""
-        regex = re.compile(r'\${([a-zA-Z0-9.]*)}')
-        return regex.findall(string)
+
+        return TOKENIZED_FIELD_PATTERN.findall(string)
 
     def _fill_in_out_edges(self) -> None:
         for i in range(len(self.vertices)):
@@ -320,7 +343,7 @@ class CloudformationLocalGraph(LocalGraph):
                 self.out_edges[i] = []
 
     def get_resources_types_in_graph(self) -> List[str]:
-        pass
+        return []
 
     def _create_edges(self) -> None:
         self._add_resource_attr_connections(ResourceAttributes.DEPENDS_ON)
@@ -344,7 +367,7 @@ class CloudformationLocalGraph(LocalGraph):
             self.in_edges[dest_vertex_index].append(edge)
 
     @staticmethod
-    def _is_of_type(cfndict, identifier, *template_sections):
+    def _is_of_type(cfndict: dict[str, Any], identifier: Any, *template_sections: TemplateSections) -> bool:
         if isinstance(identifier, str):
             for ts in template_sections:
                 ts_var = cfndict.get(ts, {})
@@ -354,6 +377,17 @@ class CloudformationLocalGraph(LocalGraph):
                     return True
         return False
 
+    def update_vertices_configs(self) -> None:
+        # not used
+        pass
+
+    @staticmethod
+    def update_vertex_config(
+        vertex: Block, changed_attributes: list[str] | dict[str, Any], dynamic_blocks: bool = False
+    ) -> None:
+        # not used
+        pass
+
 
 def get_only_dict_items(origin_dict: Union[Dict[str, Any], Any]) -> Dict[str, Dict[str, Any]]:
     if not isinstance(origin_dict, dict):
