@@ -30,10 +30,11 @@ from checkov.runner_filter import RunnerFilter
 
 if TYPE_CHECKING:
     from networkx import DiGraph
+    from checkov.common.checks_infra.registry import Registry
     from checkov.common.images.image_referencer import Image
 
 
-class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
+class Runner(ImageReferencerMixin[None], BaseRunner[CloudformationGraphManager]):
     check_type = CheckType.CLOUDFORMATION  # noqa: CCE003  # a static attribute
 
     def __init__(
@@ -54,12 +55,14 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
             if graph_manager is not None
             else CloudformationGraphManager(source=source, db_connector=db_connector)
         )
-        self.definitions_raw = {}
-        self.graph_registry = get_graph_checks_registry(self.check_type)
+        self.context: "dict[str, dict[str, Any]]" = {}
+        self.definitions: "dict[str, dict[str, Any]]" = {}  # type:ignore[assignment]  # need to check, how to support subclass differences
+        self.definitions_raw: "dict[str, list[tuple[int, str]]]" = {}
+        self.graph_registry: "Registry" = get_graph_checks_registry(self.check_type)
 
     def run(
             self,
-            root_folder: str,
+            root_folder: str | None,
             external_checks_dir: list[str] | None = None,
             files: list[str] | None = None,
             runner_filter: RunnerFilter | None = None,
@@ -95,8 +98,10 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
                     if vertex.block_type == BlockType.RESOURCE:
                         report.add_resource(f'{vertex.path}:{vertex.id}')
                 self.graph_manager.save_graph(local_graph)
-                self.definitions, self.breadcrumbs = convert_graph_vertices_to_definitions(local_graph.vertices,
-                                                                                           root_folder)
+                self.definitions, self.breadcrumbs = convert_graph_vertices_to_definitions(
+                    vertices=local_graph.vertices,
+                    root_folder=root_folder,
+                )
 
         # TODO: replace with real graph rendering
         for cf_file in self.definitions.keys():
@@ -136,7 +141,7 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
 
         return report
 
-    def check_definitions(self, root_folder: str, runner_filter: RunnerFilter, report: Report) -> None:
+    def check_definitions(self, root_folder: str | None, runner_filter: RunnerFilter, report: Report) -> None:
         for file_abs_path, definition in self.definitions.items():
             cf_file = f"/{os.path.relpath(file_abs_path, root_folder)}"
             self.pbar.set_additional_data({'Current File Scanned': cf_file})
@@ -145,13 +150,12 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
                     resource_id = ContextParser.extract_cf_resource_id(resource, resource_name)
                     # check that the resource can be parsed as a CF resource
                     if resource_id:
-                        resource_context = self.context[file_abs_path][
-                            TemplateSections.RESOURCES][resource_name]
+                        resource_context = self.context[file_abs_path][TemplateSections.RESOURCES][resource_name]
                         entity_lines_range = [resource_context['start_line'], resource_context['end_line']]
                         entity_code_lines = resource_context['code_lines']
                         if entity_lines_range and entity_code_lines:
                             # TODO - Variable Eval Message!
-                            variable_evaluations = {}
+                            variable_evaluations: "dict[str, Any]" = {}
                             skipped_checks = resource_context.get("skipped_checks")
                             entity = {resource_name: resource}
                             results = cfn_registry.scan(cf_file, entity, skipped_checks, runner_filter)
@@ -177,7 +181,7 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
                                         severity=check.severity
                                     )
 
-                                    if CHECKOV_CREATE_GRAPH:
+                                    if CHECKOV_CREATE_GRAPH and self.breadcrumbs:
                                         breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
                                         if breadcrumb:
                                             record = GraphRecord(record, breadcrumb)
@@ -195,7 +199,7 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
             self.pbar.update()
         self.pbar.close()
 
-    def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter) -> Report:
+    def get_graph_checks_report(self, root_folder: str | None, runner_filter: RunnerFilter) -> Report:
         report = Report(self.check_type)
         checks_results = self.run_graph_checks_results(runner_filter, self.check_type)
 
@@ -204,9 +208,9 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
                 entity = check_result["entity"]
                 if entity.get(CustomAttributes.BLOCK_TYPE) != BlockType.RESOURCE:
                     continue
-                entity_file_abs_path = entity.get(CustomAttributes.FILE_PATH)
+                entity_file_abs_path = entity[CustomAttributes.FILE_PATH]
                 entity_file_path = f"/{os.path.relpath(entity_file_abs_path, root_folder)}"
-                entity_name = entity.get(CustomAttributes.BLOCK_NAME).split(".")[-1]
+                entity_name = entity[CustomAttributes.BLOCK_NAME].split(".")[-1]
                 entity_context = self.context[entity_file_abs_path][TemplateSections.RESOURCES][
                     entity_name
                 ]
@@ -218,7 +222,7 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
                     code_block=entity_context.get("code_lines"),
                     file_path=entity_file_path,
                     file_line_range=[entity_context.get("start_line"), entity_context.get("end_line")],
-                    resource=entity.get(CustomAttributes.ID),
+                    resource=entity[CustomAttributes.ID],
                     evaluations={},
                     check_class=check.__class__.__module__,
                     file_abs_path=entity_file_abs_path,
