@@ -120,10 +120,13 @@ class BcPlatformIntegration:
             self.prisma_policy_filters_url = f"{self.prisma_api_url}/filter/policy/suggest"
         else:
             self.api_url = self.bc_api_url
-        self.guidelines_api_url = f"{self.api_url}/api/v1/guidelines"
+        self.guidelines_api_url = f"{self.api_url}/api/v2/guidelines"
+        self.guidelines_api_url_backoff = f"{self.api_url}/api/v1/guidelines"
+
         self.integrations_api_url = f"{self.api_url}/api/v1/integrations/types/checkov"
         self.onboarding_url = f"{self.api_url}/api/v1/signup/checkov"
-        self.platform_run_config_url = f"{self.api_url}/api/v1/checkov/runConfiguration"
+        self.platform_run_config_url = f"{self.api_url}/api/v2/checkov/runConfiguration"
+        self.platform_run_config_url_backoff = f"{self.api_url}/api/v1/checkov/runConfiguration"
 
     def is_prisma_integration(self) -> bool:
         if self.bc_api_key and not self.is_bc_token(self.bc_api_key):
@@ -538,6 +541,9 @@ class BcPlatformIntegration:
     def get_run_config_url(self) -> str:
         return f'{self.platform_run_config_url}?module={"bc" if self.is_bc_token(self.bc_api_key) else "pc"}'
 
+    def get_run_config_url_backoff(self) -> str:
+        return f'{self.platform_run_config_url_backoff}?module={"bc" if self.is_bc_token(self.bc_api_key) else "pc"}'
+
     def get_customer_run_config(self) -> None:
         if self.skip_download is True:
             logging.debug("Skipping customer run config API call")
@@ -561,14 +567,19 @@ class BcPlatformIntegration:
                 logging.error("HTTP manager was not correctly created")
                 return
 
+            platform_type = PRISMA_PLATFORM if self.is_prisma_integration() else BRIDGECREW_PLATFORM
+
             url = self.get_run_config_url()
             logging.debug(f'Platform run config URL: {url}')
             request = self.http.request("GET", url, headers=headers)  # type:ignore[no-untyped-call]
-            platform_type = PRISMA_PLATFORM if self.is_prisma_integration() else BRIDGECREW_PLATFORM
             if request.status != 200:
-                error_message = get_auth_error_message(request.status, self.is_prisma_integration(), False)
-                logging.error(error_message)
-                raise BridgecrewAuthError(error_message)
+                url = self.get_run_config_url_backoff()
+                logging.debug(f'Platform run config URL: {url}')
+                request = self.http.request("GET", url, headers=headers)  # type:ignore[no-untyped-call]
+                if request.status != 200:
+                    error_message = get_auth_error_message(request.status, self.is_prisma_integration(), False)
+                    logging.error(error_message)
+                    raise BridgecrewAuthError(error_message)
             self.customer_run_config_response = json.loads(request.data.decode("utf8"))
 
             logging.debug(f"Got customer run config from {platform_type} platform")
@@ -676,6 +687,9 @@ class BcPlatformIntegration:
                 return
 
             request = self.http.request("GET", self.guidelines_api_url, headers=headers)  # type:ignore[no-untyped-call]
+            if request.status >= 300:
+                request = self.http.request("GET", self.guidelines_api_url_backoff, headers=headers)  # type:ignore[no-untyped-call]
+
             self.public_metadata_response = json.loads(request.data.decode("utf8"))
             platform_type = PRISMA_PLATFORM if self.is_prisma_integration() else BRIDGECREW_PLATFORM
             logging.debug(f"Got checkov mappings and guidelines from {platform_type} platform")
