@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Callable, TYPE_CHECKING
+from typing import Any, Callable, TYPE_CHECKING, Tuple, List, Dict, Optional
 
 from checkov.common.graph.checks_infra.enums import SolverType
 from checkov.common.graph.checks_infra.solvers.base_solver import BaseSolver
@@ -10,12 +10,12 @@ if TYPE_CHECKING:
 
 
 class BaseFilterSolver(BaseSolver):
-    def __init__(self, resource_types: list[str], attribute: str | None, value: Any) -> None:
+    def __init__(self, resource_types: List[str], attribute: Optional[str], value: Any) -> None:
         super().__init__(SolverType.FILTER)
         self.resource_types = resource_types
         self.attribute = attribute
         self.value = value
-        self.vertices: list[dict[str, Any]] = []
+        self.vertices: List[Dict[str, Any]] = []
 
     def get_operation(self, *args: Any, **kwargs: Any) -> bool:
         raise NotImplementedError()
@@ -23,5 +23,5 @@ class BaseFilterSolver(BaseSolver):
     def _get_operation(self, *args: Any, **kwargs: Any) -> Callable[..., bool]:
         raise NotImplementedError()
 
-    def run(self, graph_connector: DiGraph) -> tuple[list[dict[str, Any]], list[dict[str, Any]]]:
+    def run(self, graph_connector: DiGraph) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]], List[Dict[str, Any]]]:
         raise NotImplementedError()
