@@ -14,7 +14,7 @@ from termcolor import colored
 
 from checkov.common.bridgecrew.severities import BcSeverities
 from checkov.common.bridgecrew.check_type import CheckType
-from checkov.common.models.enums import CheckResult
+from checkov.common.models.enums import CheckResult, ErrorStatus
 from checkov.common.typing import _ExitCodeThresholds
 from checkov.common.output.record import Record, SCA_PACKAGE_SCAN_CHECK_NAME
 from checkov.common.util.consts import PARSE_ERROR_FAIL_FLAG, CHECKOV_RUN_SCA_PACKAGE_SCAN_V2
@@ -52,6 +52,10 @@ class Report:
         self.resources: set[str] = set()
         self.extra_resources: set[ExtraResource] = set()
         self.image_cached_results: List[dict[str, Any]] = []
+        self.error_status: ErrorStatus = ErrorStatus.SUCCESS
+
+    def set_error_status(self, error_status: ErrorStatus) -> None:
+        self.error_status = error_status
 
     def add_parsing_errors(self, errors: "Iterable[str]") -> None:
         for file in errors:
