@@ -14,7 +14,6 @@ from checkov.common.output.record import Record
 from checkov.common.output.report import Report, merge_reports
 from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.runners.base_runner import BaseRunner, CHECKOV_CREATE_GRAPH
-from checkov.common.typing import _CheckResult
 from checkov.kubernetes.checks.resource.registry import registry
 from checkov.kubernetes.graph_builder.local_graph import KubernetesLocalGraph
 from checkov.kubernetes.graph_manager import KubernetesGraphManager
@@ -25,6 +24,7 @@ from checkov.kubernetes.kubernetes_utils import (
     get_skipped_checks,
     get_resource_id,
     K8_POSSIBLE_ENDINGS,
+    PARENT_RESOURCE_ID_KEY_NAME,
 )
 from checkov.runner_filter import RunnerFilter
 
@@ -34,6 +34,7 @@ if TYPE_CHECKING:
     from checkov.common.checks.base_check import BaseCheck
     from checkov.common.graph.checks_infra.base_check import BaseGraphCheck
     from checkov.common.images.image_referencer import Image
+    from checkov.common.typing import _CheckResult, _EntityContext
 
 
 class TimeoutError(Exception):
@@ -182,12 +183,13 @@ class Runner(ImageReferencerMixin[None], BaseRunner[KubernetesGraphManager]):
         # Moves report generation logic out of run() method in Runner class.
         # Allows function overriding of a much smaller function than run() for other "child" frameworks such as Kustomize, Helm
         # Where Kubernetes CHECKS are needed, but the specific file references are to another framework for the user output (or a mix of both).
-        if not self.context:
-            # this shouldn't happen
-            logging.error("Context for Kubernetes runner was not set")
-            return report
 
         if results:
+            if not self.context:
+                # this shouldn't happen
+                logging.error("Context for Kubernetes runner was not set")
+                return report
+
             for check, check_result in results.items():
                 resource_id = get_resource_id(entity_conf)
                 if not resource_id:
@@ -240,18 +242,12 @@ class Runner(ImageReferencerMixin[None], BaseRunner[KubernetesGraphManager]):
         if not checks_results:
             return report
 
-        if not self.context:
-            # this shouldn't happen
-            logging.error("Context for Kubernetes runner was not set")
-            return report
-
         for check, check_results in checks_results.items():
             for check_result in check_results:
                 entity = check_result["entity"]
                 entity_file_path = entity[CustomAttributes.FILE_PATH]
                 entity_file_abs_path = _get_entity_abs_path(root_folder, entity_file_path)
-                entity_id = entity[CustomAttributes.ID]
-                entity_context = self.context[entity_file_path][entity_id]
+                entity_context = self.get_entity_context(entity=entity, entity_file_path=entity_file_path)
 
                 clean_check_result: _CheckResult = {
                     "result": check_result["result"],
@@ -262,9 +258,9 @@ class Runner(ImageReferencerMixin[None], BaseRunner[KubernetesGraphManager]):
                     check_id=check.id,
                     check_name=check.name,
                     check_result=clean_check_result,
-                    code_block=entity_context.get("code_lines"),
+                    code_block=entity_context.get("code_lines") or [],
                     file_path=get_relative_file_path(entity_file_abs_path, root_folder),
-                    file_line_range=[entity_context.get("start_line"), entity_context.get("end_line")],
+                    file_line_range=[entity_context.get("start_line") or 0, entity_context.get("end_line") or 0],
                     resource=entity[CustomAttributes.ID],
                     evaluations={},
                     check_class=check.__class__.__module__,
@@ -275,6 +271,32 @@ class Runner(ImageReferencerMixin[None], BaseRunner[KubernetesGraphManager]):
                 report.add_record(record=record)
         return report
 
+    def get_entity_context(self, entity: dict[str, Any], entity_file_path: str) -> _EntityContext:
+        """Extract the context for the given entity
+
+        Deal with nested pods within a deployment.
+        May have K8S graph adjacencies, but will not be in the self.context map of objects.
+        (Consider them 'virtual' objects created for the sake of graph lookups)
+        """
+
+        entity_context: _EntityContext = {}
+
+        if PARENT_RESOURCE_ID_KEY_NAME in entity:
+            if entity[CustomAttributes.RESOURCE_TYPE] == "Pod":
+                # self.context not being None is checked in the caller method
+                entity_context = self.context[entity_file_path][entity[PARENT_RESOURCE_ID_KEY_NAME]]  # type:ignore[index]
+            else:
+                logging.info(
+                    "Unsupported nested resource type for Kubernetes graph edges. "
+                    f"Type: {entity[CustomAttributes.RESOURCE_TYPE]} Parent: {entity[PARENT_RESOURCE_ID_KEY_NAME]}"
+                )
+        else:
+            entity_id = entity[CustomAttributes.ID]
+            # self.context not being None is checked in the caller method
+            entity_context = self.context[entity_file_path][entity_id]  # type:ignore[index]
+
+        return entity_context
+
     def extract_images(
         self,
         graph_connector: DiGraph | None = None,
