@@ -381,10 +381,18 @@ def create_package_overview_table_part(
                         dep_sign = ""
                     else:
                         dep_sign = package_table.vertical_char
+            package_name_col_val = ""
+            if is_sub_dep_changed:
+                if dep_sign:
+                    package_name_col_val = " ".join([dep_sign, package_name])
+                else:
+                    package_name_col_val = package_name
+            elif dep_sign:
+                package_name_col_val = dep_sign
 
             package_table.add_row(
                 [
-                    " ".join([dep_sign, package_name if is_sub_dep_changed else ""]),
+                    package_name_col_val,
                     cve["id"],
                     cve["severity"],
                     package_version if is_sub_dep_changed else "",
